=======
molotov
=======

.. image:: http://coveralls.io/repos/github/loads/molotov/badge.svg?branch=master
   :target: https://coveralls.io/github/loads/molotov?branch=master

.. image:: http://travis-ci.org/loads/molotov.svg?branch=master
   :target: https://travis-ci.org/loads/molotov

.. image:: http://readthedocs.org/projects/molotov/badge/?version=latest
   :target: https://molotov.readthedocs.io

.. image:: https://img.shields.io/pypi/pyversions/molotov.svg
   :target: https://molotov.readthedocs.io


Simple Python 3.6+ tool to write load tests.

Based on `asyncio <https://docs.python.org/3/library/asyncio.html>`_,
Built with `aiohttp <http://aiohttp.readthedocs.io>`_ 3.x

`Full Documentation <https://molotov.readthedocs.io>`_

